@@ -8,7 +8,7 @@ use File::Spec 3.33;
 use File::Spec::Functions 'catfile', 'catdir', 'canonpath';
 use File::Temp 0.22 ();
 
-our $VERSION = '0.0200';
+our $VERSION = '0.020001';
 
 # ABSTRACT: Simple file/directory based CAS implementation
 
@@ -521,7 +521,7 @@ DataStore::CAS::Simple - Simple file/directory based CAS implementation
 
 =head1 VERSION
 
-version 0.0200
+version 0.020001
 
 =head1 DESCRIPTION
 
@@ -536,8 +536,8 @@ copying a File object from one instance to another is optimized by hard-linking
 the underlying file.
 
   # This is particularly fast:
-  $cas1= DataStore::CAS::Simple( path => 'foo' );
-  $cas2= DataStore::CAS::Simple( path => 'bar' );
+  $cas1= DataStore::CAS::Simple->new( path => 'foo' );
+  $cas2= DataStore::CAS::Simple->new( path => 'bar' );
   $cas1->put( $cas2->get( $hash ) );
 
 This class does not perform any sort of optimization on the storage of the
